package recoverymap;

use strict;
use Plugins;
use Globals;
use Log qw(message error debug warning);
use Misc;
use Utils;
use AI;

Plugins::register('recoverymap', 'move somewhere before sitting down to regen', \&unload);
my $mainLoopHook = Plugins::addHook('AI_pre', \&mainLoop);

sub unload {
	Plugins::delHook('AI_pre', $mainLoopHook);
}

sub mainLoop {
	my $weight = main::percent_weight($char);
	if (AI::action eq "sitAuto" &&
	   !AI::args->{recoveryMap} &&
           !$char->{sitting} &&
	   ($weight < 50 || $config{'sitAuto_over_50'})) {
		AI::args->{recoveryMap} = 1;
		my $brak = 0;
		for (my $i = 0; exists $config{"recoveryMap_$i"}; $i++) {
			my $prefix = "recoveryMap_$i";
			debug "[recoveryMap] > Checking $prefix block...\n", "recoveryMap";
			next if (!$config{$prefix});
			next if ($brak);

			# determine the set maps to use
			if (my $mapsList = $config{$prefix}) {
				# Read the maps list
				my $in_map = '';					
				my @maps = split(/\s*,\s*/, $mapsList);
				my $found_map = 0;
				foreach my $map_name (@maps) {
					if ($field{name} =~ $map_name) {
						$found_map = 1;
						$in_map = $field{name};
					}
				}
				if ($found_map == 1) {
					my %lockField;
					main::getField($in_map, \%lockField);

					my ($lockX, $lockY);
					my $i = 500;
					if ($config{$prefix."_x"} ne '' || $config{$prefix."_y"} ne '') {
						do {
							$lockX = int($config{$prefix."_x"}) if ($config{$prefix."_x"} ne '');
							$lockX = int(rand($field{width}) + 1) if (!$config{$prefix."_x"} && $config{$prefix."_y"});
							$lockX += (int(rand($config{$prefix."_randX"}))+1) if ($config{$prefix."_randX"} ne '');
			    				$lockY = int($config{$prefix."_y"}) if ($config{$prefix."_y"} ne '');
			    				$lockY = int(rand($field{width}) + 1) if (!$config{$prefix."_y"} && $config{$prefix."_x"});
							$lockY += (int(rand($config{$prefix."_randY"}))+1) if ($config{$prefix."_randY"} ne '');
						} while (--$i && !Misc::checkFieldWalkable(\%lockField, $lockX, $lockY));
					}
					if (!$i) {
						error "Invalid coordinates specified for recoveryMap, coordinates are unwalkable\n";
						$in_map = '';
					} else {
						if (defined $lockX || defined $lockY) {
							Log::message "Calculating recovery route to: $maps_lut{$in_map.'.rsw'}($in_map): $lockX, $lockY\n", "route";
						} else {
							Log::message "Calculating recovery route to: $maps_lut{$in_map.'.rsw'}($in_map)\n", "route";
						}
						main::ai_route($in_map, $lockX, $lockY, attackOnRoute => 1, noSitAuto => 1);
						$brak = 1;
					}
					
				}

			}
		}
	}
}

return 1;